NAME

HiD::Generator::Markdown - Markdown Processor for HiD

VERSION

version 0.001

DESCRIPTION

This generator searches for all markdown files within the HiD working directory and generates html pages from them.

ATTRIBUTES

markdown files

all found markdown files

AUTHOR

Dominik Meyer <dmeyer@federationhq.de>

COPYRIGHT AND LICENSE

This software is copyright (c) 2018 by Dominik Meyer.

This is free software; you can redistribute it and/or modify it under the same terms as the Perl 5 programming language system itself.